@@ -1,7 +1,9 @@
 CERTIFICATE_AUTHORITY_OBJECT_CLASS = 'certificationAuthority'
 TRUSTED_DOMAIN_OBJECT_CLASS = 'trustedDomain'
 COMPUTER_OBJECT_CLASS = 'computer'
+CONTAINER_OBJECT_CLASS = 'container'
 GROUP_OBJECT_CLASS = 'group'
+ORGANIZATIONAL_UNIT_OBJECT_CLASS = 'organizationalUnit'
 POSIX_GROUP_OBJECT_CLASS = 'posixGroup'
 POSIX_USER_OBJECT_CLASS = 'posixAccount'
 USER_OBJECT_CLASS = 'user'
@@ -24,7 +26,9 @@ AD_ATTRIBUTE_GET_ALL_NON_VIRTUAL_ATTRS = '*'
 # keys for common active directory attributes
 AD_ATTRIBUTE_SAMACCOUNT_NAME = 'sAMAccountName'
 AD_ATTRIBUTE_SECURITY_DESCRIPTOR = 'ntSecurityDescriptor'
+AD_ATTRIBUTE_CANONICAL_NAME = 'canonicalName'
 AD_ATTRIBUTE_COMMON_NAME = 'cn'
+AD_ATTRIBUTE_NAME = 'name'
 AD_ATTRIBUTE_OBJECT_CLASS = 'objectClass'
 AD_ATTRIBUTE_OBJECT_SID = 'objectSID'
 AD_ATTRIBUTE_NETBIOS_NAME = 'nETBIOSName'
@@ -103,3 +107,7 @@ VALUE_TO_FIND_ANY_WITH_ATTRIBUTE_POPULATED = '*'
 # miscellaneous values we need
 UNKNOWN_USER_POSIX_UID = -1
 UNKNOWN_GROUP_POSIX_GID = -1
+
+# LDAP Error codes
+OP_SUCCESS = 0
+NO_SUCH_OBJECT = 32
